@@ -1,5 +1,5 @@
 /*
- * $Id: di.c,v 2.56 2009-11-22 13:26:11-08 bll Exp $
+ * $Id: di.c,v 2.58 2009-11-29 17:42:57-08 bll Exp $
  * $Source: /home/bll/DI/RCS/di.c,v $
  *
  * Copyright 1994-2009 Brad Lanam, Walnut Creek, CA
@@ -87,21 +87,21 @@
 #include "version.h"
 
 #include <stdio.h>
+#if _hdr_stdlib
+# include <stdlib.h>
+#endif
+#if _sys_types
+# include <sys/types.h>
+#endif
 #if _hdr_ctype
 # include <ctype.h>
 #endif
 #if _hdr_errno
 # include <errno.h>
 #endif
-#if _hdr_stdlib
-# include <stdlib.h>
-#endif
 #if _hdr_getopt
 # include <getopt.h>
 #endif
-#if _sys_types
-# include <sys/types.h>
-#endif
 #if _hdr_string
 # include <string.h>
 #endif
@@ -114,9 +114,6 @@
 #if _include_malloc && _hdr_malloc
 # include <malloc.h>
 #endif
-#if _hdr_math
-# include <math.h>
-#endif
 #if _hdr_unistd
 # include <unistd.h>
 #endif
@@ -143,8 +140,6 @@
   extern "C" {
 #endif
 
-extern int di_lib_debug;
-
 #if _npt_getenv
   extern char *getenv _((char *));
 #endif
@@ -326,7 +321,7 @@ typedef struct {
     char            haspooledfs;
 } diData_t;
 
-static int          debug = { 0 };
+int          debug = { 0 };
 
 static sizeTable_t sizeTable [] =
 {
@@ -743,12 +738,16 @@ printDiskInfo (diData)
     char                tempSortType [DI_SORT_MAX + 1];
 
     lastpool[0] = '\0';
-    memset ((char *) &totals, '\0', sizeof (diDiskInfo_t));
-    totals.blockSize = 8192;
-    strncpy (totals.name, DI_GT("Total"), DI_NAME_LEN);
-    totals.printFlag = DI_PRNT_OK;
-
     diopts = &diData->options;
+
+    if ((diopts->flags & DI_F_TOTAL) == DI_F_TOTAL)
+    {
+        memset ((char *) &totals, '\0', sizeof (diDiskInfo_t));
+        totals.blockSize = 8192;
+        strncpy (totals.name, DI_GT("Total"), DI_NAME_LEN);
+        totals.printFlag = DI_PRNT_OK;
+    }
+
     if ((diopts->flags & DI_F_NO_HEADER) != DI_F_NO_HEADER)
     {
         printTitle (diopts);
@@ -2319,7 +2318,6 @@ processArgs (argc, argv, diData, dbsstr)
             case 'D':
             {
                 debug = atoi (optarg);
-                di_lib_debug = debug;
                 break;
             }
 
@@ -2446,7 +2444,6 @@ processArgs (argc, argv, diData, dbsstr)
             case 'X':
             {
                 debug = atoi (optarg);
-                di_lib_debug = debug;
                 diopts->flags |= DI_F_DEBUG_HDR | DI_F_TOTAL;
                 diopts->flags &= ~ DI_F_NO_HEADER;
                 diopts->width = 10;
