@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: cflags.sh,v 1.39 2009-11-22 16:05:50-08 bll Exp $
+# $Id: cflags.sh,v 1.40 2009-11-23 14:31:40-08 bll Exp $
 # $Source: /home/bll/DI/features.base/RCS/cflags.sh,v $
 # Copyright 2001-2008 Brad Lanam, Walnut Creek, California USA
 #
@@ -100,8 +100,6 @@ then
     libs="${LIBS:-}"
 fi
 
-vers="`${CC} -v 2>&1`" # attempt to get version...
-
 if [ "${xgetconf}" != "" ]
 then
     tccflags="`${xgetconf} LFS_CFLAGS 2>/dev/null`"
@@ -110,22 +108,34 @@ then
 fi
 
 gccflags=""
+
+# check for gcc...
+${CC} -v 2>&1 | $xgrep 'gcc version' > /dev/null 2>&1
+rc=$?
+if [ $rc -eq 0 ]
+then
+    usinggcc="Y"
+fi
+
 # -Wtraditional
 case ${CC} in
     *gcc*)
         usinggcc="Y"
-        gccflags="-Wall -Waggregate-return -Wconversion -Wformat -Wmissing-prototypes -Wmissing-declarations -Wnested-externs -Wpointer-arith -Wshadow -Wstrict-prototypes -Wunused"
-        vers=""  # we know it's gcc...don't run again
-        case "${bit64}" in
-            1)
-                ccflags="-m64 $ccflags"
-                ;;
-        esac
         ;;
 esac
 
+if [ "$usinggcc" = "Y" ]
+then
+    gccflags="-Wall -Waggregate-return -Wconversion -Wformat -Wmissing-prototypes -Wmissing-declarations -Wnested-externs -Wpointer-arith -Wshadow -Wstrict-prototypes -Wunused"
+    case "${bit64}" in
+        1)
+            ccflags="-m64 $ccflags"
+            ;;
+    esac
+fi
+
 TCC=${CC}
-if [ ${usinggcc} = "Y" ]
+if [ "${usinggcc}" = "Y" ]
 then
   TCC=gcc
 fi
