@@ -1,7 +1,7 @@
 #!/bin/sh
 #
-# $Id: obj_ext.sh,v 1.7 2008-05-25 20:31:36-07 bll Exp $
-# $Source: /export/home/bll/DI/features.base/RCS/obj_ext.sh,v $
+# $Id: obj_ext.sh,v 1.8 2009-11-22 16:05:53-08 bll Exp $
+# $Source: /home/bll/DI/features.base/RCS/obj_ext.sh,v $
 # Copyright 2001-2008 Brad Lanam, Walnut Creek, California, USA
 #
 
@@ -37,11 +37,11 @@ then
     eval `cat object_ext`
 fi
 
-echo "OBJ_EXT=${OBJ_EXT}" > object_ext
+echo "OBJ_EXT=${OBJ_EXT};" > object_ext
 echo "EXE_EXT=${EXE_EXT}" >> object_ext
-echo "OBJ_EXT=${OBJ_EXT}"
-echo "EXE_EXT=${EXE_EXT}"
-echo "export OBJ_EXT"
+echo "OBJ_EXT=${OBJ_EXT};"
+echo "EXE_EXT=${EXE_EXT};"
+echo "export OBJ_EXT;"
 echo "export EXE_EXT"
 
 exit 0
