@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: turnoffnls.sh,v 1.1 2005-10-12 09:15:23-07 bll Exp $
+# $Id: turnoffnls.sh,v 1.2 2006-10-05 00:51:54-07 bll Exp $
 #
 
 ed config.h << HERE > /dev/null
@@ -18,6 +18,8 @@ g/^#define[     ]*_hdr_locale/ s/1//
 g/^#define[     ]*_hdr_locale/ s/^#define/#undef/
 g/^#define[     ]*_command_msgfmt/ s/1//
 g/^#define[     ]*_command_msgfmt/ s/^#define/#undef/
+g/^#define[     ]*_command_gmsgfmt/ s/1//
+g/^#define[     ]*_command_gmsgfmt/ s/^#define/#undef/
 w
 q
 HERE
