@@ -1,6 +1,6 @@
 /*
-$Id: getopt.c,v 1.8 2008-05-25 20:33:01-07 bll Exp $
-$Source: /export/home/bll/DI/RCS/getopt.c,v $
+$Id: getopt.c,v 1.10 2009-11-23 11:23:48-08 bll Exp $
+$Source: /home/bll/DI/RCS/getopt.c,v $
 */
 
 #include "config.h"
@@ -9,7 +9,7 @@ $Source: /export/home/bll/DI/RCS/getopt.c,v $
 
 /*
  *
- * $Id: getopt.c,v 1.8 2008-05-25 20:33:01-07 bll Exp $
+ * $Id: getopt.c,v 1.10 2009-11-23 11:23:48-08 bll Exp $
  *
  * getopt - get option letter from argv
  *
@@ -18,6 +18,9 @@ $Source: /export/home/bll/DI/RCS/getopt.c,v $
  */
 
 #include <stdio.h>
+#if _hdr_stdlib
+# include <stdlib.h>
+#endif
 #if _hdr_string
 # include <string.h>
 #endif
@@ -103,6 +106,6 @@ getopt (argc, argv, optstring)
 
 #else
 
-extern int di_lib_debug;
+extern int debug;
 
 #endif
