@@ -1,7 +1,7 @@
 /*
-$Id: hasnls.c,v 1.5 2008-05-25 20:32:58-07 bll Exp $
-$Source: /export/home/bll/DI/RCS/hasnls.c,v $
-Copyright 2006-2008 Brad Lanam, Walnut Creek, CA
+$Id: hasnls.c,v 1.6 2009-09-08 16:20:31-07 bll Exp $
+$Source: /home/bll/DI/RCS/hasnls.c,v $
+Copyright 2006-2009 Brad Lanam, Walnut Creek, CA
 */
 
 #include "config.h"
