@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: mkconfig.pl,v 1.31 2009-11-22 09:16:37-08 bll Exp $
+# $Id: mkconfig.pl,v 1.38 2009-11-28 17:04:34-08 bll Exp $
 #
 # Copyright 2006-2009 Brad Lanam Walnut Creek, CA USA
 #
@@ -43,13 +43,14 @@ check_run
     my ($name, $code, $r_val, $r_clist, $r_config, $r_a) = @_;
 
     my $rc = check_link ($name, $code, $r_clist, $r_config,
-        { 'incheaders' => 'all', 'nounlink' => 1, 'tryextern' => 0, %$r_a, });
-    print LOGFH "##  run test: $rc\n";
+        { 'incheaders' => 'all', %$r_a, });
+    print LOGFH "##  run test: link: $rc\n";
     $$r_val = 0;
     if ($rc == 0)
     {
         $rc = system ("./$name.exe > $name.out");
         if ($rc & 127) { exitmkconfig ($rc); }
+        print LOGFH "##  run test: run: $rc\n";
         if ($rc == 0)
         {
             open (CRFH, "<$name.out");
@@ -58,10 +59,6 @@ check_run
             close CRFH;
         }
     }
-    unlink "$name.exe";
-    unlink "$name.c";
-    unlink "$name.out";
-    unlink "$name.o";
     return $rc;
 }
 
@@ -114,34 +111,10 @@ check_link
           }
         }
       }
-
-      if ($rc != 0 && $r_a->{'tryextern'} == 1)
-      {
-        $rc = _check_link ($name, { 'cflags' => '-D_TRY_extern_=1',
-            'otherlibs' => $otherlibs, } );
-        if ($rc == 0)
-        {
-          my $r_hash = $r_config->{'reqlibs'};
-          my @vals = split (/\s+/, $otherlibs);
-          $dlibs = '';
-          foreach my $val (@vals)
-          {
-              if ($val eq '') { next; }
-              $r_hash->{$val} = 1;
-              $dlibs .= $val . ' ';
-          }
-        }
-      }
     }
 
     $r_a->{'dlibs'} = $dlibs;
 
-    if ($r_a->{'nounlink'} == 0)
-    {
-        unlink "$name.exe";
-        unlink "$name.c";
-        unlink "$name.o";
-    }
     return $rc;
 }
 
@@ -196,61 +169,9 @@ check_compile
     $rc = system ("$cmd >> $LOG 2>&1");
     if ($rc & 127) { exitmkconfig ($rc); }
     print LOGFH "##  compile test: $rc\n";
-    unlink "$name.c";
-    unlink "$name.o";
     return $rc;
 }
 
-sub
-check_cpp
-{
-    my ($name, $code, $r_clist, $r_config, $r_a) = @_;
-
-    open (CCFH, ">$name.c");
-
-    print CCFH $precc;
-    my $hdrs = print_headers ($r_a, $r_clist, $r_config);
-    print CCFH $hdrs;
-    print CCFH $code;
-    close CCFH;
-
-    my $cmd = "$ENV{'CC'} $ENV{'CFLAGS'} -E $name.c > /dev/null 2>&1";
-    print LOGFH "##  cpp test: $cmd\n";
-    my $rc = system ("cat $name.c >> $LOG");
-    if ($rc & 127) { exitmkconfig ($rc); }
-    $rc = system ("$cmd >> $LOG 2>&1");
-    if ($rc & 127) { exitmkconfig ($rc); }
-    print LOGFH "##  cpp test: $rc\n";
-    unlink "$name.c";
-    return $rc;
-}
-
-sub
-check_dashe
-{
-    my ($name, $r_clist, $r_config) = @_;
-
-    print LOGFH "## [$name] $ENV{'CC'} supports -E ... \n";
-    print STDERR "$ENV{'CC'} supports -E ... ";
-    my $code = <<"_HERE_";
-main () { exit (0); }
-_HERE_
-    my $rc = 1;
-    $rc = check_cpp ($name, $code, $r_clist, $r_config,
-        { 'incheaders' => 'none', });
-    if ($rc == 0)
-    {
-        print LOGFH "## [$name] yes\n";
-        print STDERR "yes\n";
-    }
-    else
-    {
-        print LOGFH "## [$name] no\n";
-        print STDERR "no\n";
-    }
-    $r_config->{$name} = $rc;
-}
-
 sub
 check_header
 {
@@ -271,16 +192,8 @@ _HERE_
 main () { exit (0); }
 _HERE_
     my $rc = 1;
-    if ($r_config->{'_supports_dash_e'} eq '1')
-    {
-        $rc = check_cpp ($name, $code, $r_clist, $r_config,
-            { 'incheaders' => 'std', });
-    }
-    else
-    {
-        $rc = check_compile ($name, $code, $r_clist, $r_config,
-            { 'incheaders' => 'std', });
-    }
+    $rc = check_compile ($name, $code, $r_clist, $r_config,
+        { 'incheaders' => 'std', });
     my $val = 0;
     if ($rc == 0)
     {
@@ -381,9 +294,7 @@ _HERE_
 
     my %a = (
          'incheaders' => 'all',
-         'nounlink' => 0,
          'otherlibs' => $val,
-         'tryextern' => 0,
          );
     my $rc = check_link ($name, $code, $r_clist, $r_config, \%a);
     if ($rc == 0)
@@ -655,9 +566,7 @@ _HERE_
 
     my %a = (
          'incheaders' => 'all',
-         'nounlink' => 0,
          'otherlibs' => $val,
-         'tryextern' => 0,
          );
     my $rc = check_link ($name, $code, $r_clist, $r_config, \%a);
     if ($rc == 0)
@@ -693,7 +602,7 @@ check_setmntent_1arg
 main () { setmntent ("/etc/mnttab"); }
 _HERE_
     my $rc = check_link ($name, $code, $r_clist, $r_config,
-        { 'incheaders' => 'all', 'nounlink' => 0, 'otherlibs' => undef, 'tryextern' => 0, });
+        { 'incheaders' => 'all', 'otherlibs' => undef, });
     if ($rc == 0)
     {
         $r_config->{$name} = 1;
@@ -720,7 +629,7 @@ check_setmntent_2arg
 main () { setmntent ("/etc/mnttab", "r"); }
 _HERE_
     my $rc = check_link ($name, $code, $r_clist, $r_config,
-        { 'incheaders' => 'all', 'nounlink' => 0, 'otherlibs' => undef, 'tryextern' => 0, });
+        { 'incheaders' => 'all', 'otherlibs' => undef, });
     if ($rc == 0)
     {
         $r_config->{$name} = 1;
@@ -750,7 +659,7 @@ main () {
 }
 _HERE_
     my $rc = check_link ($name, $code, $r_clist, $r_config,
-        { 'incheaders' => 'all', 'nounlink' => 0, 'otherlibs' => undef, 'tryextern' => 0, });
+        { 'incheaders' => 'all', 'otherlibs' => undef, });
     if ($rc == 0)
     {
         $r_config->{$name} = 1;
@@ -780,7 +689,7 @@ main () {
 }
 _HERE_
     my $rc = check_link ($name, $code, $r_clist, $r_config,
-        { 'incheaders' => 'all', 'nounlink' => 0, 'otherlibs' => undef, 'tryextern' => 0, });
+        { 'incheaders' => 'all', 'otherlibs' => undef, });
     if ($rc == 0)
     {
         $r_config->{$name} = 1;
@@ -810,7 +719,7 @@ main () {
 }
 _HERE_
     my $rc = check_link ($name, $code, $r_clist, $r_config,
-        { 'incheaders' => 'all', 'nounlink' => 0, 'otherlibs' => undef, 'tryextern' => 0, });
+        { 'incheaders' => 'all', 'otherlibs' => undef, });
     if ($rc == 0)
     {
         $r_config->{$name} = 1;
@@ -946,13 +855,11 @@ create_config
     open (CCOFH, ">../config.h");
     print CCOFH <<'_HERE_';
 
-#ifndef _config_H
-#define _config_H 1
+#ifndef __INC_CONFIG_H
+#define __INC_CONFIG_H 1
 
 _HERE_
 
-    check_dashe ('_supports_dash_e', \@clist, \%config);
-
     # FreeBSD has buggy headers, requires sys/param.h as a required include.
     # always check for these headers.
     my @headlist1 = (
@@ -990,10 +897,8 @@ _HERE_
 
         if ($inheaders && $line !~ m#^(hdr|sys)#o)
         {
-            if ($config{'_hdr_malloc'} ne '0')
-            {
-                check_include_malloc ('_include_malloc', \@clist, \%config);
-            }
+            check_include_malloc ('_include_malloc', \@clist, \%config);
+            check_include_string ('_include_string', \@clist, \%config);
             $inheaders = 0;
         }
 
@@ -1004,6 +909,7 @@ _HERE_
         }
         elsif ($ininclude == 1)
         {
+            $line =~ s,\\\\,\\,go;
             $include .= $line . "\n";
         }
         elsif ($line =~ m#^include$#o)
@@ -1035,17 +941,6 @@ _HERE_
             {
                 check_header ($nm, $hdr, \@clist, \%config,
                     { 'reqhdr' => \@oh, });
-
-                if ((($hdr eq 'strings.h' &&
-                      defined ($config{'_hdr_string'}) &&
-                      $config{'_hdr_string'} ne '0') ||
-                     ($hdr eq 'string.h' &&
-                      defined ($config{'_hdr_strings'}) &&
-                      $config{'_hdr_strings'} ne '0')) &&
-                    ! defined ($config{'_include_string'}))
-                {
-                    check_include_string ('_include_string', \@clist, \%config);
-                }
             }
         }
         elsif ($line =~ m#^command\s+(.*)#o)
@@ -1181,7 +1076,7 @@ _HERE_
     {
         if ($config{$val} eq '0')
         {
-            print CCOFH "#undef $val\n";
+            print CCOFH "#undef  $val\n";
         }
         else
         {
@@ -1220,7 +1115,10 @@ _HERE_
 
     print CCOFH <<'_HERE_';
 
-#endif /* _config_H */
+#define _mkconfig_sh 0
+#define _mkconfig_pl 1
+
+#endif /* __INC_CONFIG_H */
 _HERE_
     close CCOFH;
 
@@ -1240,9 +1138,11 @@ if (! defined ($ARGV[0]) ||
     exit 1;
 }
 
-if (! -d $TMP) { mkdir $TMP, 0777; }
+if (-d $TMP) { system ("rm -rf $TMP"); }
+mkdir $TMP, 0777;
 chdir $TMP;
 
+print "$0 using $ARGV[0]\n";
 unlink $LOG;
 open (LOGFH, ">>$LOG");
 $ENV{'CFLAGS'} = $ENV{'CFLAGS'} . ' ' . $ENV{'CINCLUDES'};
@@ -1256,4 +1156,5 @@ create_config;
 close LOGFH;
 
 chdir "..";
-rmdir $TMP;
+if (-d $TMP) { system ("rm -rf $TMP"); }
+exit 0;
